@@ -37,6 +37,10 @@ class PlayMediaCommand(Command):
     :type delay: (optional) int
     :param description: A user-provided description of this command.
     :type description: (optional) str
+    :param screen_lock: If true, disable the Interaction Timer.
+    :type screen_lock: (optional) bool
+    :param sequencer: Specify the sequencer that should execute this command.
+    :type sequencer: (optional) str
     :param when: If false, the execution of the command is skipped. Defaults to true.
     :type when: (optional) bool
     :param audio_track: The command to issue on the media player
@@ -51,6 +55,8 @@ class PlayMediaCommand(Command):
         'object_type': 'str',
         'delay': 'int',
         'description': 'str',
+        'screen_lock': 'bool',
+        'sequencer': 'str',
         'when': 'bool',
         'audio_track': 'ask_sdk_model.interfaces.alexa.presentation.apl.audio_track.AudioTrack',
         'component_id': 'str',
@@ -61,6 +67,8 @@ class PlayMediaCommand(Command):
         'object_type': 'type',
         'delay': 'delay',
         'description': 'description',
+        'screen_lock': 'screenLock',
+        'sequencer': 'sequencer',
         'when': 'when',
         'audio_track': 'audioTrack',
         'component_id': 'componentId',
@@ -68,14 +76,18 @@ class PlayMediaCommand(Command):
     }  # type: Dict
     supports_multiple_types = False
 
-    def __init__(self, delay=None, description=None, when=None, audio_track=None, component_id=None, source=None):
-        # type: (Union[int, str, None], Optional[str], Optional[bool], Optional[AudioTrack_485ca517], Optional[str], Optional[List[VideoSource_96b69bdd]]) -> None
+    def __init__(self, delay=None, description=None, screen_lock=None, sequencer=None, when=None, audio_track=None, component_id=None, source=None):
+        # type: (Union[int, str, None], Optional[str], Optional[bool], Optional[str], Optional[bool], Optional[AudioTrack_485ca517], Optional[str], Optional[List[VideoSource_96b69bdd]]) -> None
         """Plays media on a media player (currently only a Video player; audio may be added in the future). The media may be on the background audio track or may be sequenced with speak directives).
 
         :param delay: The delay in milliseconds before this command starts executing; must be non-negative. Defaults to 0.
         :type delay: (optional) int
         :param description: A user-provided description of this command.
         :type description: (optional) str
+        :param screen_lock: If true, disable the Interaction Timer.
+        :type screen_lock: (optional) bool
+        :param sequencer: Specify the sequencer that should execute this command.
+        :type sequencer: (optional) str
         :param when: If false, the execution of the command is skipped. Defaults to true.
         :type when: (optional) bool
         :param audio_track: The command to issue on the media player
@@ -88,7 +100,7 @@ class PlayMediaCommand(Command):
         self.__discriminator_value = "PlayMedia"  # type: str
 
         self.object_type = self.__discriminator_value
-        super(PlayMediaCommand, self).__init__(object_type=self.__discriminator_value, delay=delay, description=description, when=when)
+        super(PlayMediaCommand, self).__init__(object_type=self.__discriminator_value, delay=delay, description=description, screen_lock=screen_lock, sequencer=sequencer, when=when)
         self.audio_track = audio_track
         self.component_id = component_id
         self.source = source
