@@ -35,6 +35,10 @@ class SetValueCommand(Command):
     :type delay: (optional) int
     :param description: A user-provided description of this command.
     :type description: (optional) str
+    :param screen_lock: If true, disable the Interaction Timer.
+    :type screen_lock: (optional) bool
+    :param sequencer: Specify the sequencer that should execute this command.
+    :type sequencer: (optional) str
     :param when: If false, the execution of the command is skipped. Defaults to true.
     :type when: (optional) bool
     :param component_id: The id of the component whose value to set.
@@ -49,6 +53,8 @@ class SetValueCommand(Command):
         'object_type': 'str',
         'delay': 'int',
         'description': 'str',
+        'screen_lock': 'bool',
+        'sequencer': 'str',
         'when': 'bool',
         'component_id': 'str',
         'object_property': 'str',
@@ -59,6 +65,8 @@ class SetValueCommand(Command):
         'object_type': 'type',
         'delay': 'delay',
         'description': 'description',
+        'screen_lock': 'screenLock',
+        'sequencer': 'sequencer',
         'when': 'when',
         'component_id': 'componentId',
         'object_property': 'property',
@@ -66,14 +74,18 @@ class SetValueCommand(Command):
     }  # type: Dict
     supports_multiple_types = False
 
-    def __init__(self, delay=None, description=None, when=None, component_id=None, object_property=None, value=None):
-        # type: (Union[int, str, None], Optional[str], Optional[bool], Optional[str], Optional[str], Optional[str]) -> None
+    def __init__(self, delay=None, description=None, screen_lock=None, sequencer=None, when=None, component_id=None, object_property=None, value=None):
+        # type: (Union[int, str, None], Optional[str], Optional[bool], Optional[str], Optional[bool], Optional[str], Optional[str], Optional[str]) -> None
         """Change a dynamic property of a component without redrawing the screen.
 
         :param delay: The delay in milliseconds before this command starts executing; must be non-negative. Defaults to 0.
         :type delay: (optional) int
         :param description: A user-provided description of this command.
         :type description: (optional) str
+        :param screen_lock: If true, disable the Interaction Timer.
+        :type screen_lock: (optional) bool
+        :param sequencer: Specify the sequencer that should execute this command.
+        :type sequencer: (optional) str
         :param when: If false, the execution of the command is skipped. Defaults to true.
         :type when: (optional) bool
         :param component_id: The id of the component whose value to set.
@@ -86,7 +98,7 @@ class SetValueCommand(Command):
         self.__discriminator_value = "SetValue"  # type: str
 
         self.object_type = self.__discriminator_value
-        super(SetValueCommand, self).__init__(object_type=self.__discriminator_value, delay=delay, description=description, when=when)
+        super(SetValueCommand, self).__init__(object_type=self.__discriminator_value, delay=delay, description=description, screen_lock=screen_lock, sequencer=sequencer, when=when)
         self.component_id = component_id
         self.object_property = object_property
         self.value = value
