@@ -36,6 +36,10 @@ class SpeakListCommand(Command):
     :type delay: (optional) int
     :param description: A user-provided description of this command.
     :type description: (optional) str
+    :param screen_lock: If true, disable the Interaction Timer.
+    :type screen_lock: (optional) bool
+    :param sequencer: Specify the sequencer that should execute this command.
+    :type sequencer: (optional) str
     :param when: If false, the execution of the command is skipped. Defaults to true.
     :type when: (optional) bool
     :param align: 
@@ -54,6 +58,8 @@ class SpeakListCommand(Command):
         'object_type': 'str',
         'delay': 'int',
         'description': 'str',
+        'screen_lock': 'bool',
+        'sequencer': 'str',
         'when': 'bool',
         'align': 'ask_sdk_model.interfaces.alexa.presentation.apl.align.Align',
         'component_id': 'str',
@@ -66,6 +72,8 @@ class SpeakListCommand(Command):
         'object_type': 'type',
         'delay': 'delay',
         'description': 'description',
+        'screen_lock': 'screenLock',
+        'sequencer': 'sequencer',
         'when': 'when',
         'align': 'align',
         'component_id': 'componentId',
@@ -75,14 +83,18 @@ class SpeakListCommand(Command):
     }  # type: Dict
     supports_multiple_types = False
 
-    def __init__(self, delay=None, description=None, when=None, align=None, component_id=None, count=None, minimum_dwell_time=None, start=None):
-        # type: (Union[int, str, None], Optional[str], Optional[bool], Optional[Align_70ae0466], Optional[str], Union[int, str, None], Union[int, str, None], Union[int, str, None]) -> None
+    def __init__(self, delay=None, description=None, screen_lock=None, sequencer=None, when=None, align=None, component_id=None, count=None, minimum_dwell_time=None, start=None):
+        # type: (Union[int, str, None], Optional[str], Optional[bool], Optional[str], Optional[bool], Optional[Align_70ae0466], Optional[str], Union[int, str, None], Union[int, str, None], Union[int, str, None]) -> None
         """Read the contents of a range of items inside a common container. Each item will scroll into view before speech. Each item should have a speech property, but it is not required.
 
         :param delay: The delay in milliseconds before this command starts executing; must be non-negative. Defaults to 0.
         :type delay: (optional) int
         :param description: A user-provided description of this command.
         :type description: (optional) str
+        :param screen_lock: If true, disable the Interaction Timer.
+        :type screen_lock: (optional) bool
+        :param sequencer: Specify the sequencer that should execute this command.
+        :type sequencer: (optional) str
         :param when: If false, the execution of the command is skipped. Defaults to true.
         :type when: (optional) bool
         :param align: 
@@ -99,7 +111,7 @@ class SpeakListCommand(Command):
         self.__discriminator_value = "SpeakList"  # type: str
 
         self.object_type = self.__discriminator_value
-        super(SpeakListCommand, self).__init__(object_type=self.__discriminator_value, delay=delay, description=description, when=when)
+        super(SpeakListCommand, self).__init__(object_type=self.__discriminator_value, delay=delay, description=description, screen_lock=screen_lock, sequencer=sequencer, when=when)
         self.align = align
         self.component_id = component_id
         self.count = count
