@@ -22,9 +22,9 @@ from ask_sdk_model.directive import Directive
 
 
 if typing.TYPE_CHECKING:
-    from typing import Dict, List, Optional, Union
+    from typing import Dict, List, Optional, Union, Any
     from datetime import datetime
-    from ask_sdk_model.interfaces.connections.connections_status import ConnectionsStatus
+    from ask_sdk_model.interfaces.connections.connections_status import ConnectionsStatus as ConnectionsStatus_145c3ef2
 
 
 class SendResponseDirective(Directive):
@@ -52,7 +52,7 @@ class SendResponseDirective(Directive):
     supports_multiple_types = False
 
     def __init__(self, status=None, payload=None):
-        # type: (Optional[ConnectionsStatus], Optional[Dict[str, object]]) -> None
+        # type: (Optional[ConnectionsStatus_145c3ef2], Optional[Dict[str, object]]) -> None
         """This is the directive that a skill can send as part of their response to a session based request to return a response to ConnectionsRequest.
 
         :param status: 
