@@ -22,11 +22,11 @@ from ask_sdk_model.interfaces.display.template import Template
 
 
 if typing.TYPE_CHECKING:
-    from typing import Dict, List, Optional, Union
+    from typing import Dict, List, Optional, Union, Any
     from datetime import datetime
-    from ask_sdk_model.interfaces.display.back_button_behavior import BackButtonBehavior
-    from ask_sdk_model.interfaces.display.image import Image
-    from ask_sdk_model.interfaces.display.list_item import ListItem
+    from ask_sdk_model.interfaces.display.list_item import ListItem as ListItem_79a19afb
+    from ask_sdk_model.interfaces.display.image import Image as Image_1942d978
+    from ask_sdk_model.interfaces.display.back_button_behavior import BackButtonBehavior as BackButtonBehavior_46c3eb02
 
 
 class ListTemplate1(Template):
@@ -64,7 +64,7 @@ class ListTemplate1(Template):
     supports_multiple_types = False
 
     def __init__(self, token=None, back_button=None, background_image=None, title=None, list_items=None):
-        # type: (Optional[str], Optional[BackButtonBehavior], Optional[Image], Optional[str], Optional[List[ListItem]]) -> None
+        # type: (Optional[str], Optional[BackButtonBehavior_46c3eb02], Optional[Image_1942d978], Optional[str], Optional[List[ListItem_79a19afb]]) -> None
         """
 
         :param token: 
