@@ -21,9 +21,9 @@ from enum import Enum
 
 
 if typing.TYPE_CHECKING:
-    from typing import Dict, List, Optional, Union
+    from typing import Dict, List, Optional, Union, Any
     from datetime import datetime
-    from ask_sdk_model.interfaces.system.error_type import ErrorType
+    from ask_sdk_model.interfaces.system.error_type import ErrorType as ErrorType_9b83cec0
 
 
 class Error(object):
@@ -47,7 +47,7 @@ class Error(object):
     supports_multiple_types = False
 
     def __init__(self, object_type=None, message=None):
-        # type: (Optional[ErrorType], Optional[str]) -> None
+        # type: (Optional[ErrorType_9b83cec0], Optional[str]) -> None
         """
 
         :param object_type: 
