@@ -23,7 +23,7 @@ from enum import Enum
 if typing.TYPE_CHECKING:
     from typing import Dict, List, Optional, Union, Any
     from datetime import datetime
-    from ask_sdk_model.services.reminder_management.alert_info_spoken_info import AlertInfoSpokenInfo as AlertInfoSpokenInfo_3eafce07
+    from ask_sdk_model.services.reminder_management.alert_info_spoken_info import SpokenInfo as SpokenInfo_e1d2a971
 
 
 class AlertInfo(object):
@@ -32,11 +32,11 @@ class AlertInfo(object):
 
 
     :param spoken_info: 
-    :type spoken_info: (optional) ask_sdk_model.services.reminder_management.alert_info_spoken_info.AlertInfoSpokenInfo
+    :type spoken_info: (optional) ask_sdk_model.services.reminder_management.alert_info_spoken_info.SpokenInfo
 
     """
     deserialized_types = {
-        'spoken_info': 'ask_sdk_model.services.reminder_management.alert_info_spoken_info.AlertInfoSpokenInfo'
+        'spoken_info': 'ask_sdk_model.services.reminder_management.alert_info_spoken_info.SpokenInfo'
     }  # type: Dict
 
     attribute_map = {
@@ -45,11 +45,11 @@ class AlertInfo(object):
     supports_multiple_types = False
 
     def __init__(self, spoken_info=None):
-        # type: (Optional[AlertInfoSpokenInfo_3eafce07]) -> None
+        # type: (Optional[SpokenInfo_e1d2a971]) -> None
         """Alert info for VUI / GUI
 
         :param spoken_info: 
-        :type spoken_info: (optional) ask_sdk_model.services.reminder_management.alert_info_spoken_info.AlertInfoSpokenInfo
+        :type spoken_info: (optional) ask_sdk_model.services.reminder_management.alert_info_spoken_info.SpokenInfo
         """
         self.__discriminator_value = None  # type: str
 
